@@ -4,6 +4,7 @@ import datetime
 import json
 import logging
 
+from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models import Model, ManyToManyField
 from django.db.models.fields.files import FieldFile
@@ -46,7 +47,9 @@ def _set_original_fields(instance):
                 original_fields[field] = getattr(instance,
                                                  '{0}_id'.format(field))
             else:
-                original_fields[field] = getattr(instance, field)
+                # Do not store deferred fields
+                if field in instance.__dict__:
+                    original_fields[field] = getattr(instance, field)
 
     for field in getattr(instance, '_tracked_fields', []):
         _set_original_field(instance, field)
@@ -114,7 +117,8 @@ def _create_event(instance, action):
             user = None
     return TrackingEvent.objects.create(
         action=action,
-        object=instance,
+        object_content_type=ContentType.objects.get_for_model(instance),
+        object_id=instance.pk if isinstance(instance.pk, int) else None,
         object_repr=repr(instance),
         user=user,
         user_repr=user_repr,
@@ -227,6 +231,8 @@ def _create_update_tracking_related_event(instance):
 
     # Create the events from the events dict
     for related_field, fields in events.items():
+        if related_field[1] == '+':
+            continue
         try:
             related_instances = getattr(instance, related_field[1])
         except ObjectDoesNotExist:
